#
# spec file for package python-pyside-shiboken
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define tarname    shiboken
Name:           python-pyside-%{tarname}
Version:        1.2.2
Release:        14.2
%define majorver   %(echo "%{version}" | sed 's/\\.[0-9]*$//')
%define libsoname  %(echo "%{majorver}" | sed 's/\\./_/')
%define libprefix  lib%{tarname}
%define py_ver_mod %(python -c "import sys; sys.stdout.write(sys.version[:3].replace('.','_'))")
%define libpyname  %{libprefix}-python%{py_ver}
%define libname    %{libprefix}-python%{py_ver_mod}-%{libsoname}
%define pyname     Shiboken
Summary:        Generate CPython bindings from C++ code
License:        GPL-2.0
Group:          Development/Libraries/C and C++
Url:            http://qt-project.org/wiki/PySide
Source0:        http://download.qt-project.org/official_releases/pyside/%{tarname}-%{version}.tar.bz2
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libqt4-devel
BuildRequires:  libxml2-devel
BuildRequires:  libxslt-devel
BuildRequires:  python-devel
Obsoletes:      libapiextractor < %{version}
Provides:       libapiextractor = %{version}
Obsoletes:      libapiextractor-doc < %{version}
Provides:       libapiextractor-doc = %{version}
Obsoletes:      libgenrunner < %{version}
Provides:       libgenrunner = %{version}
Requires:       %{libname} = %{version}
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description
Shiboken generates C++ code for CPython extensions. It is similar to
BoostPythonGenerator from boost::python, but is designed to create smaller
code.

%package -n %{libname}
Summary:        Generate CPython bindings from C++ code
License:        LGPL-2.1
Group:          Development/Libraries/C and C++

%description -n %{libname}
Shiboken generates C++ code for CPython extensions. It is similar to
BoostPythonGenerator from boost::python, but is designed to create smaller
code.

%package doc
Summary:        Documentation for %{name}
License:        GPL-2.0
Group:          Development/Libraries/C and C++
Recommends:     %{libname} = %{version}

%description doc
Documentation and manuals for %{name}

%package -n %{libprefix}-devel
Summary:        Development files for %{name}
License:        LGPL-2.1
Group:          Development/Libraries/C and C++
Recommends:     %{libname} = %{version}
# As cmake config files are not python version agnostic, python2 and 3 versions of developement
# package can't be installed at the same time
Conflicts:      lib%{tarname}-python3-devel
Requires:       cmake
Requires:       libqt4-devel
Requires:       libxml2-devel
Requires:       libxslt-devel
Requires:       python-devel

%description -n %{libprefix}-devel
Development libraries and headers needed to build software using %{name}

%prep
%setup -q -n %{tarname}-%{version}

%build
mkdir build
pushd build
cmake .. \
  -DCMAKE_INSTALL_PREFIX=%{_prefix} \
  -DLIB_SUFFIX=$(echo %{_lib} | cut -b4-)  \
  -DCMAKE_BUILD_TYPE=Debug \
  -DBUILD_TESTS=False
make %{?_smp_mflags}
make doc

%install
pushd build
%makeinstall DESTDIR=%{buildroot}
mv %{buildroot}%{_bindir}/%{tarname} %{buildroot}%{_bindir}/%{tarname}-%{py_ver}
mv %{buildroot}%{_mandir}/man1/%{tarname}.1 %{buildroot}%{_mandir}/man1/%{tarname}-%{py_ver}.1
%fdupes %{buildroot}

%pre
[ -h %{_bindir}/%{tarname} ] || rm -f %{_bindir}/%{tarname}
[ -h %{_mandir}/man1/%{tarname}.1.gz ] || rm -f %{_mandir}/man1/%{tarname}.1.gz

%post
/sbin/ldconfig
update-alternatives --install %{_bindir}/%{tarname} %{tarname} %{_bindir}/%{tarname}-%{py_ver} 20 \
                    --slave %{_mandir}/man1/%{tarname}.1.gz %{tarname}.1 %{_mandir}/man1/%{tarname}-%{py_ver}.1.gz

%preun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove %{tarname} %{_bindir}/%{tarname}-%{py_ver}
fi

%postun -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig
%post   -n %{libname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc COPYING ChangeLog
%if 0%{?suse_version} >= 1230
%ghost %{_sysconfdir}/alternatives/%{tarname}
%ghost %{_sysconfdir}/alternatives/%{tarname}.1
%endif
%ghost %{_bindir}/%{tarname}
%{_bindir}/%{tarname}-%{py_ver}
%{_mandir}/man1/%{tarname}-%{py_ver}.1.gz
%ghost %{_mandir}/man1/%{tarname}.1.gz
%{python_sitearch}/%{tarname}.so

%files -n %{libname}
%defattr(-,root,root)
%doc COPYING.%{libprefix}
%{_libdir}/%{libpyname}.so.*

%files doc
%defattr(-,root,root)
%doc COPYING
%doc doc/

%files -n %{libprefix}-devel
%defattr(-,root,root)
%{_includedir}/%{tarname}/
%{_libdir}/%{libpyname}.so
%{_libdir}/cmake/%{pyname}-%{version}/
%{_libdir}/pkgconfig/%{tarname}.pc

%changelog
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashisms in pre script
* Thu May  8 2014 toddrme2178@gmail.com
- Update to 1.2.2
  * Fix building with python 3.3 and 3.4.
  * Refactor and improve added function resolving
  * Bug fixes.
- Remove upstream patch shiboken-1.2.1-cmake-find-python3.3.patch
* Fri Feb  7 2014 dimstar@opensuse.org
- Fix %%post scriptlets: /sbin/ldconfig can't be the parser of
  the script: it does not know how to do it (remove -p).
* Sun Dec 29 2013 p.drouand@gmail.com
- Implement update-alternative support to avoid conflict between
  python and python3 package on a same system
- Add a Conflict tag in devel subpackage in both python/3 package;
  Cmake config files are unfortunately not python-version agnostic
  and generate conflicts between the two packages
- Remove renaming of pkgconfig file in python3 package; it's not needed
  as the two packages are conflicting
* Thu Dec 19 2013 p.drouand@gmail.com
- Specfile clean-up
- Remove obsolete conditionnal macros
- Remove depreciated %%{py_requires} macro
- Fix Group; standard is Devel/Languages/Python
* Tue Aug 27 2013 fisiu@opensuse.org
- Update to 1.2.1:
  * Bug fixes.
  * Fix build in C++11 mode.
- Update tarball url.
* Wed Oct 10 2012 scorot@free.fr
- Fix build requirements for SLE 11 SP2
* Wed Aug 29 2012 toddrme2178@gmail.com
- Update to 1.1.2
  * bugfix release
* Mon Apr 23 2012 toddrme2178@gmail.com
- Add python 3 package
* Fri Apr 20 2012 toddrme2178@gmail.com
- Update to version 1.1.1
  * Unified toolchain! No more GeneratorRunner and ApiExtractor,
    now you just need Shiboken to compile PySide.
  * Bug Fixes;
- Removed references to GeneratorRunner and ApiExtractor in spec
  file
* Wed Feb  8 2012 toddrme2178@gmail.com
- Rename package to python-pyside-shiboken to match pattern used by other pyside packages
- Update to version 1.1.0
- spec file cleanup
- Build and package documentation
* Fri Oct 21 2011 cgoncalves@opensuse.org
- update to version 1.0.9
* Wed Sep 21 2011 cgoncalves@opensuse.org
- update to version 1.0.7
* Thu Sep  1 2011 cgoncalves@opensuse.org
- update to version 1.0.6
* Wed Jul 27 2011 cgoncalves@opensuse.org
- update to version 1.0.5
* Thu Jun 23 2011 cgoncalves@opensuse.org
- update to version 1.0.4
* Thu May 26 2011 cgoncalves@opensuse.org
- update to version 1.0.3
* Mon May  2 2011 cgoncalves@opensuse.org
- update to version 1.0.2
* Mon Apr  4 2011 cgoncalves@opensuse.org
- update to version 1.0.1
* Thu Mar  3 2011 cgoncalves@opensuse.org
- update to version 1.0.0
* Mon Feb 21 2011 cgoncalves@opensuse.org
- update to version 1.0.0~rc1
* Wed Feb  2 2011 cgoncalves@opensuse.org
- update to version 1.0.0~beta5
* Wed Jan 26 2011 cgoncalves@opensuse.org
- fix build
* Sun Jan 23 2011 cgoncalves@opensuse.org
- update to version 1.0.0~beta4
* Sun Jan 16 2011 cgoncalves@opensuse.org
- fix build on Mandriva
* Mon Jan 10 2011 cgoncalves@opensuse.org
- update to version 1.0.0~beta3
* Tue Dec 21 2010 cgoncalves@opensuse.org
- update to version 1.0.0~beta2
* Mon Dec  6 2010 cgoncalves@opensuse.org
- update to version 1.0.0~beta1
* Mon Oct 18 2010 cgoncalves@opensuse.org
- update to version 0.5.1
* Mon Sep 13 2010 cgoncalves@opensuse.org
- update to version 0.5.0
* Wed Aug  4 2010 cgoncalves@opensuse.org
- update to version 0.4.0
* Thu Jun  3 2010 cgoncalves@opensuse.org
- update to version 0.3.2
* Tue May  4 2010 cgoncalves@opensuse.org
- update to version 0.3.1
* Mon May  3 2010 cgoncalves@opensuse.org
- update to version 0.3.0
* Tue Mar 23 2010 cgoncalves@opensuse.org
- initial package (version 0.2)
